// Models.swift
//
// Generated by swagger-codegen
// https://github.com/swagger-api/swagger-codegen
//

import Foundation

protocol JSONEncodable {
    func encodeToJSON() -> AnyObject
}

public enum ErrorResponse : ErrorType {
    case Error(Int, NSData?, ErrorType)
}

public class Response<T> {
    public let statusCode: Int
    public let header: [String: String]
    public let body: T?

    public init(statusCode: Int, header: [String: String], body: T?) {
        self.statusCode = statusCode
        self.header = header
        self.body = body
    }

    public convenience init(response: NSHTTPURLResponse, body: T?) {
        let rawHeader = response.allHeaderFields
        var header = [String:String]()
        for case let (key, value) as (String, String) in rawHeader {
            header[key] = value
        }
        self.init(statusCode: response.statusCode, header: header, body: body)
    }
}

private var once = dispatch_once_t()
class Decoders {
    static private var decoders = Dictionary<String, ((AnyObject) -> AnyObject)>()

    static func addDecoder<T>(clazz clazz: T.Type, decoder: ((AnyObject) -> T)) {
        let key = "\(T.self)"
        decoders[key] = { decoder($0) as! AnyObject }
    }

    static func decode<T>(clazz clazz: [T].Type, source: AnyObject) -> [T] {
        let array = source as! [AnyObject]
        return array.map { Decoders.decode(clazz: T.self, source: $0) }
    }

    static func decode<T, Key: Hashable>(clazz clazz: [Key:T].Type, source: AnyObject) -> [Key:T] {
        let sourceDictionary = source as! [Key: AnyObject]
        var dictionary = [Key:T]()
        for (key, value) in sourceDictionary {
            dictionary[key] = Decoders.decode(clazz: T.self, source: value)
        }
        return dictionary
    }

    static func decode<T>(clazz clazz: T.Type, source: AnyObject) -> T {
        initialize()
        if T.self is Int32.Type && source is NSNumber {
            return source.intValue as! T;
        }
        if T.self is Int64.Type && source is NSNumber {
            return source.longLongValue as! T;
        }
        if T.self is NSUUID.Type && source is String {
            return NSUUID(UUIDString: source as! String) as! T
        }
        if source is T {
            return source as! T
        }
        if T.self is NSData.Type && source is String {
            return NSData(base64EncodedString: source as! String, options: NSDataBase64DecodingOptions()) as! T
        }

        let key = "\(T.self)"
        if let decoder = decoders[key] {
           return decoder(source) as! T
        } else {
            fatalError("Source \(source) is not convertible to type \(clazz): Maybe swagger file is insufficient")
        }
    }

    static func decodeOptional<T>(clazz clazz: T.Type, source: AnyObject?) -> T? {
        if source is NSNull {
            return nil
        }
        return source.map { (source: AnyObject) -> T in
            Decoders.decode(clazz: clazz, source: source)
        }
    }

    static func decodeOptional<T>(clazz clazz: [T].Type, source: AnyObject?) -> [T]? {
        if source is NSNull {
            return nil
        }
        return source.map { (someSource: AnyObject) -> [T] in
            Decoders.decode(clazz: clazz, source: someSource)
        }
    }

    static func decodeOptional<T, Key: Hashable>(clazz clazz: [Key:T].Type, source: AnyObject?) -> [Key:T]? {
        if source is NSNull {
            return nil
        }
        return source.map { (someSource: AnyObject) -> [Key:T] in
            Decoders.decode(clazz: clazz, source: someSource)
        }
    }

    static private func initialize() {
        dispatch_once(&once) {
            let formatters = [
                "yyyy-MM-dd",
                "yyyy-MM-dd'T'HH:mm:ssZZZZZ",
                "yyyy-MM-dd'T'HH:mm:ss.SSSZZZZZ",
                "yyyy-MM-dd'T'HH:mm:ss'Z'",
                "yyyy-MM-dd'T'HH:mm:ss.SSS"
            ].map { (format: String) -> NSDateFormatter in
                let formatter = NSDateFormatter()
                formatter.locale = NSLocale(localeIdentifier:"en_US_POSIX")
                formatter.dateFormat = format
                return formatter
            }
            // Decoder for NSDate
            Decoders.addDecoder(clazz: NSDate.self) { (source: AnyObject) -> NSDate in
               if let sourceString = source as? String {
                    for formatter in formatters {
                        if let date = formatter.dateFromString(sourceString) {
                            return date
                        }
                    }

                }
                if let sourceInt = source as? Int {
                    // treat as a java date
                    return NSDate(timeIntervalSince1970: Double(sourceInt / 1000) )
                }
                fatalError("formatter failed to parse \(source)")
            }

            // Decoder for ISOFullDate
            Decoders.addDecoder(clazz: ISOFullDate.self, decoder: { (source: AnyObject) -> ISOFullDate in
                if let string = source as? String,
                   let isoDate = ISOFullDate.from(string: string) {
                    return isoDate
                }
                fatalError("formatter failed to parse \(source)")
            }) 

            // Decoder for [Account]
            Decoders.addDecoder(clazz: [Account].self) { (source: AnyObject) -> [Account] in
                return Decoders.decode(clazz: [Account].self, source: source)
            }
            // Decoder for Account
            Decoders.addDecoder(clazz: Account.self) { (source: AnyObject) -> Account in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = Account()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.firstName = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["first_name"])
                instance.lastName = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["last_name"])
                instance.usedQuotaPrivate = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["used_quota_private"])
                instance.modifiedDate = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["modified_date"])
                instance.usedQuota = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["used_quota"])
                instance.createdDate = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["created_date"])
                instance.quota = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["quota"])
                instance.groupId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["group_id"])
                instance.institutionUserId = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["institution_user_id"])
                instance.institutionId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["institution_id"])
                instance.email = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["email"])
                instance.usedQuotaPublic = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["used_quota_public"])
                instance.pendingQuotaRequest = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["pending_quota_request"])
                instance.active = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["active"])
                instance.maximumFileSize = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["maximum_file_size"])
                return instance
            }


            // Decoder for [AccountCreate]
            Decoders.addDecoder(clazz: [AccountCreate].self) { (source: AnyObject) -> [AccountCreate] in
                return Decoders.decode(clazz: [AccountCreate].self, source: source)
            }
            // Decoder for AccountCreate
            Decoders.addDecoder(clazz: AccountCreate.self) { (source: AnyObject) -> AccountCreate in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = AccountCreate()
                instance.email = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["email"])
                instance.firstName = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["first_name"])
                instance.lastName = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["last_name"])
                instance.groupId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["group_id"])
                instance.institutionUserId = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["institution_user_id"])
                instance.symplecticUserId = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["symplectic_user_id"])
                instance.quota = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["quota"])
                instance.isActive = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_active"])
                return instance
            }


            // Decoder for [AccountGroupRoles]
            Decoders.addDecoder(clazz: [AccountGroupRoles].self) { (source: AnyObject) -> [AccountGroupRoles] in
                return Decoders.decode(clazz: [AccountGroupRoles].self, source: source)
            }
            // Decoder for AccountGroupRoles
            Decoders.addDecoder(clazz: AccountGroupRoles.self) { (source: AnyObject) -> AccountGroupRoles in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = AccountGroupRoles()
                return instance
            }


            // Decoder for [AccountGroupRolesCreate]
            Decoders.addDecoder(clazz: [AccountGroupRolesCreate].self) { (source: AnyObject) -> [AccountGroupRolesCreate] in
                return Decoders.decode(clazz: [AccountGroupRolesCreate].self, source: source)
            }
            // Decoder for AccountGroupRolesCreate
            Decoders.addDecoder(clazz: AccountGroupRolesCreate.self) { (source: AnyObject) -> AccountGroupRolesCreate in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = AccountGroupRolesCreate()
                return instance
            }


            // Decoder for [AccountReport]
            Decoders.addDecoder(clazz: [AccountReport].self) { (source: AnyObject) -> [AccountReport] in
                return Decoders.decode(clazz: [AccountReport].self, source: source)
            }
            // Decoder for AccountReport
            Decoders.addDecoder(clazz: AccountReport.self) { (source: AnyObject) -> AccountReport in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = AccountReport()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.accountId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["account_id"])
                instance.createdDate = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["created_date"])
                instance.status = AccountReport.Status(rawValue: (sourceDictionary["status"] as? String) ?? "") 
                instance.downloadUrl = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["download_url"])
                instance.groupId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["group_id"])
                return instance
            }


            // Decoder for [AccountUpdate]
            Decoders.addDecoder(clazz: [AccountUpdate].self) { (source: AnyObject) -> [AccountUpdate] in
                return Decoders.decode(clazz: [AccountUpdate].self, source: source)
            }
            // Decoder for AccountUpdate
            Decoders.addDecoder(clazz: AccountUpdate.self) { (source: AnyObject) -> AccountUpdate in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = AccountUpdate()
                instance.groupId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["group_id"])
                instance.isActive = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_active"])
                return instance
            }


            // Decoder for [Article]
            Decoders.addDecoder(clazz: [Article].self) { (source: AnyObject) -> [Article] in
                return Decoders.decode(clazz: [Article].self, source: source)
            }
            // Decoder for Article
            Decoders.addDecoder(clazz: Article.self) { (source: AnyObject) -> Article in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = Article()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.title = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["title"])
                instance.doi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["doi"])
                instance.handle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["handle"])
                instance.url = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url"])
                instance.urlPublicHtml = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url_public_html"])
                instance.urlPublicApi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url_public_api"])
                instance.urlPrivateHtml = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url_private_html"])
                instance.urlPrivateApi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url_private_api"])
                instance.timeline = Decoders.decodeOptional(clazz: Timeline.self, source: sourceDictionary["timeline"])
                instance.thumb = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["thumb"])
                instance.definedType = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["defined_type"])
                instance.definedTypeName = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["defined_type_name"])
                return instance
            }


            // Decoder for [ArticleComplete]
            Decoders.addDecoder(clazz: [ArticleComplete].self) { (source: AnyObject) -> [ArticleComplete] in
                return Decoders.decode(clazz: [ArticleComplete].self, source: source)
            }
            // Decoder for ArticleComplete
            Decoders.addDecoder(clazz: ArticleComplete.self) { (source: AnyObject) -> ArticleComplete in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ArticleComplete()
                instance.citation = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["citation"])
                instance.confidentialReason = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["confidential_reason"])
                instance.isConfidential = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_confidential"])
                instance.size = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["size"])
                instance.funding = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["funding"])
                instance.fundingList = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["funding_list"])
                instance.tags = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["tags"])
                instance.version = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["version"])
                instance.isActive = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_active"])
                instance.isMetadataRecord = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_metadata_record"])
                instance.metadataReason = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["metadata_reason"])
                instance.status = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["status"])
                instance.description = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["description"])
                instance.isEmbargoed = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_embargoed"])
                instance.isPublic = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_public"])
                instance.createdDate = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["created_date"])
                instance.hasLinkedFile = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["has_linked_file"])
                instance.categories = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["categories"])
                instance.license = Decoders.decodeOptional(clazz: License.self, source: sourceDictionary["license"])
                instance.embargoTitle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["embargo_title"])
                instance.embargoReason = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["embargo_reason"])
                instance.references = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["references"])
                instance.relatedMaterials = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["related_materials"])
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.title = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["title"])
                instance.doi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["doi"])
                instance.handle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["handle"])
                instance.url = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url"])
                instance.urlPublicHtml = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url_public_html"])
                instance.urlPublicApi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url_public_api"])
                instance.urlPrivateHtml = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url_private_html"])
                instance.urlPrivateApi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url_private_api"])
                instance.timeline = Decoders.decodeOptional(clazz: Timeline.self, source: sourceDictionary["timeline"])
                instance.thumb = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["thumb"])
                instance.definedType = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["defined_type"])
                instance.definedTypeName = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["defined_type_name"])
                instance.figshareUrl = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["figshare_url"])
                instance.downloadDisabled = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["download_disabled"])
                instance.files = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["files"])
                instance.authors = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["authors"])
                instance.customFields = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["custom_fields"])
                instance.embargoOptions = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["embargo_options"])
                return instance
            }


            // Decoder for [ArticleCompletePrivate]
            Decoders.addDecoder(clazz: [ArticleCompletePrivate].self) { (source: AnyObject) -> [ArticleCompletePrivate] in
                return Decoders.decode(clazz: [ArticleCompletePrivate].self, source: source)
            }
            // Decoder for ArticleCompletePrivate
            Decoders.addDecoder(clazz: ArticleCompletePrivate.self) { (source: AnyObject) -> ArticleCompletePrivate in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ArticleCompletePrivate()
                instance.figshareUrl = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["figshare_url"])
                instance.downloadDisabled = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["download_disabled"])
                instance.files = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["files"])
                instance.authors = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["authors"])
                instance.customFields = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["custom_fields"])
                instance.embargoOptions = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["embargo_options"])
                instance.citation = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["citation"])
                instance.confidentialReason = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["confidential_reason"])
                instance.isConfidential = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_confidential"])
                instance.size = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["size"])
                instance.funding = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["funding"])
                instance.fundingList = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["funding_list"])
                instance.tags = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["tags"])
                instance.version = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["version"])
                instance.isActive = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_active"])
                instance.isMetadataRecord = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_metadata_record"])
                instance.metadataReason = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["metadata_reason"])
                instance.status = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["status"])
                instance.description = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["description"])
                instance.isEmbargoed = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_embargoed"])
                instance.isPublic = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_public"])
                instance.createdDate = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["created_date"])
                instance.hasLinkedFile = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["has_linked_file"])
                instance.categories = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["categories"])
                instance.license = Decoders.decodeOptional(clazz: License.self, source: sourceDictionary["license"])
                instance.embargoTitle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["embargo_title"])
                instance.embargoReason = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["embargo_reason"])
                instance.references = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["references"])
                instance.relatedMaterials = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["related_materials"])
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.title = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["title"])
                instance.doi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["doi"])
                instance.handle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["handle"])
                instance.url = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url"])
                instance.urlPublicHtml = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url_public_html"])
                instance.urlPublicApi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url_public_api"])
                instance.urlPrivateHtml = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url_private_html"])
                instance.urlPrivateApi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url_private_api"])
                instance.timeline = Decoders.decodeOptional(clazz: Timeline.self, source: sourceDictionary["timeline"])
                instance.thumb = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["thumb"])
                instance.definedType = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["defined_type"])
                instance.definedTypeName = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["defined_type_name"])
                instance.accountId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["account_id"])
                return instance
            }


            // Decoder for [ArticleConfidentiality]
            Decoders.addDecoder(clazz: [ArticleConfidentiality].self) { (source: AnyObject) -> [ArticleConfidentiality] in
                return Decoders.decode(clazz: [ArticleConfidentiality].self, source: source)
            }
            // Decoder for ArticleConfidentiality
            Decoders.addDecoder(clazz: ArticleConfidentiality.self) { (source: AnyObject) -> ArticleConfidentiality in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ArticleConfidentiality()
                instance.isConfidential = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_confidential"])
                instance.reason = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["reason"])
                return instance
            }


            // Decoder for [ArticleCreate]
            Decoders.addDecoder(clazz: [ArticleCreate].self) { (source: AnyObject) -> [ArticleCreate] in
                return Decoders.decode(clazz: [ArticleCreate].self, source: source)
            }
            // Decoder for ArticleCreate
            Decoders.addDecoder(clazz: ArticleCreate.self) { (source: AnyObject) -> ArticleCreate in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ArticleCreate()
                instance.title = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["title"])
                instance.description = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["description"])
                instance.isMetadataRecord = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_metadata_record"])
                instance.metadataReason = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["metadata_reason"])
                instance.tags = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["tags"])
                instance.keywords = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["keywords"])
                instance.references = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["references"])
                instance.relatedMaterials = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["related_materials"])
                instance.categories = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["categories"])
                instance.categoriesBySourceId = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["categories_by_source_id"])
                instance.authors = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["authors"])
                instance.customFields = Decoders.decodeOptional(clazz: AnyObject.self, source: sourceDictionary["custom_fields"])
                instance.customFieldsList = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["custom_fields_list"])
                instance.definedType = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["defined_type"])
                instance.funding = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["funding"])
                instance.fundingList = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["funding_list"])
                instance.license = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["license"])
                instance.doi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["doi"])
                instance.handle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["handle"])
                instance.resourceDoi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_doi"])
                instance.resourceTitle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_title"])
                instance.timeline = Decoders.decodeOptional(clazz: TimelineUpdate.self, source: sourceDictionary["timeline"])
                instance.groupId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["group_id"])
                return instance
            }


            // Decoder for [ArticleDOI]
            Decoders.addDecoder(clazz: [ArticleDOI].self) { (source: AnyObject) -> [ArticleDOI] in
                return Decoders.decode(clazz: [ArticleDOI].self, source: source)
            }
            // Decoder for ArticleDOI
            Decoders.addDecoder(clazz: ArticleDOI.self) { (source: AnyObject) -> ArticleDOI in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ArticleDOI()
                instance.doi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["doi"])
                return instance
            }


            // Decoder for [ArticleEmbargo]
            Decoders.addDecoder(clazz: [ArticleEmbargo].self) { (source: AnyObject) -> [ArticleEmbargo] in
                return Decoders.decode(clazz: [ArticleEmbargo].self, source: source)
            }
            // Decoder for ArticleEmbargo
            Decoders.addDecoder(clazz: ArticleEmbargo.self) { (source: AnyObject) -> ArticleEmbargo in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ArticleEmbargo()
                instance.isEmbargoed = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_embargoed"])
                instance.embargoTitle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["embargo_title"])
                instance.embargoReason = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["embargo_reason"])
                instance.embargoOptions = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["embargo_options"])
                return instance
            }


            // Decoder for [ArticleEmbargoUpdater]
            Decoders.addDecoder(clazz: [ArticleEmbargoUpdater].self) { (source: AnyObject) -> [ArticleEmbargoUpdater] in
                return Decoders.decode(clazz: [ArticleEmbargoUpdater].self, source: source)
            }
            // Decoder for ArticleEmbargoUpdater
            Decoders.addDecoder(clazz: ArticleEmbargoUpdater.self) { (source: AnyObject) -> ArticleEmbargoUpdater in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ArticleEmbargoUpdater()
                instance.isEmbargoed = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_embargoed"])
                instance.embargoDate = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["embargo_date"])
                instance.embargoType = ArticleEmbargoUpdater.EmbargoType(rawValue: (sourceDictionary["embargo_type"] as? String) ?? "") 
                instance.embargoTitle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["embargo_title"])
                instance.embargoReason = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["embargo_reason"])
                instance.embargoOptions = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["embargo_options"])
                return instance
            }


            // Decoder for [ArticleHandle]
            Decoders.addDecoder(clazz: [ArticleHandle].self) { (source: AnyObject) -> [ArticleHandle] in
                return Decoders.decode(clazz: [ArticleHandle].self, source: source)
            }
            // Decoder for ArticleHandle
            Decoders.addDecoder(clazz: ArticleHandle.self) { (source: AnyObject) -> ArticleHandle in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ArticleHandle()
                instance.handle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["handle"])
                return instance
            }


            // Decoder for [ArticleProjectCreate]
            Decoders.addDecoder(clazz: [ArticleProjectCreate].self) { (source: AnyObject) -> [ArticleProjectCreate] in
                return Decoders.decode(clazz: [ArticleProjectCreate].self, source: source)
            }
            // Decoder for ArticleProjectCreate
            Decoders.addDecoder(clazz: ArticleProjectCreate.self) { (source: AnyObject) -> ArticleProjectCreate in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ArticleProjectCreate()
                instance.title = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["title"])
                instance.description = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["description"])
                instance.tags = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["tags"])
                instance.keywords = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["keywords"])
                instance.references = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["references"])
                instance.relatedMaterials = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["related_materials"])
                instance.categories = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["categories"])
                instance.categoriesBySourceId = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["categories_by_source_id"])
                instance.authors = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["authors"])
                instance.customFields = Decoders.decodeOptional(clazz: AnyObject.self, source: sourceDictionary["custom_fields"])
                instance.customFieldsList = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["custom_fields_list"])
                instance.definedType = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["defined_type"])
                instance.funding = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["funding"])
                instance.fundingList = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["funding_list"])
                instance.license = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["license"])
                instance.doi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["doi"])
                instance.handle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["handle"])
                instance.resourceDoi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_doi"])
                instance.resourceTitle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_title"])
                instance.timeline = Decoders.decodeOptional(clazz: TimelineUpdate.self, source: sourceDictionary["timeline"])
                return instance
            }


            // Decoder for [ArticleSearch]
            Decoders.addDecoder(clazz: [ArticleSearch].self) { (source: AnyObject) -> [ArticleSearch] in
                return Decoders.decode(clazz: [ArticleSearch].self, source: source)
            }
            // Decoder for ArticleSearch
            Decoders.addDecoder(clazz: ArticleSearch.self) { (source: AnyObject) -> ArticleSearch in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ArticleSearch()
                instance.searchFor = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["search_for"])
                instance.page = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["page"])
                instance.pageSize = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["page_size"])
                instance.limit = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["limit"])
                instance.offset = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["offset"])
                instance.orderDirection = ArticleSearch.OrderDirection(rawValue: (sourceDictionary["order_direction"] as? String) ?? "") 
                instance.institution = Decoders.decodeOptional(clazz: Int32.self, source: sourceDictionary["institution"])
                instance.publishedSince = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["published_since"])
                instance.modifiedSince = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["modified_since"])
                instance.group = Decoders.decodeOptional(clazz: Int32.self, source: sourceDictionary["group"])
                instance.resourceDoi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_doi"])
                instance.itemType = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["item_type"])
                instance.doi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["doi"])
                instance.handle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["handle"])
                instance.projectId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["project_id"])
                instance.order = ArticleSearch.Order(rawValue: (sourceDictionary["order"] as? String) ?? "") 
                return instance
            }


            // Decoder for [ArticleUpdate]
            Decoders.addDecoder(clazz: [ArticleUpdate].self) { (source: AnyObject) -> [ArticleUpdate] in
                return Decoders.decode(clazz: [ArticleUpdate].self, source: source)
            }
            // Decoder for ArticleUpdate
            Decoders.addDecoder(clazz: ArticleUpdate.self) { (source: AnyObject) -> ArticleUpdate in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ArticleUpdate()
                instance.title = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["title"])
                instance.description = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["description"])
                instance.isMetadataRecord = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_metadata_record"])
                instance.metadataReason = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["metadata_reason"])
                instance.tags = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["tags"])
                instance.keywords = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["keywords"])
                instance.references = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["references"])
                instance.relatedMaterials = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["related_materials"])
                instance.categories = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["categories"])
                instance.categoriesBySourceId = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["categories_by_source_id"])
                instance.authors = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["authors"])
                instance.customFields = Decoders.decodeOptional(clazz: AnyObject.self, source: sourceDictionary["custom_fields"])
                instance.customFieldsList = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["custom_fields_list"])
                instance.definedType = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["defined_type"])
                instance.funding = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["funding"])
                instance.fundingList = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["funding_list"])
                instance.license = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["license"])
                instance.doi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["doi"])
                instance.handle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["handle"])
                instance.resourceDoi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_doi"])
                instance.resourceTitle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_title"])
                instance.timeline = Decoders.decodeOptional(clazz: TimelineUpdate.self, source: sourceDictionary["timeline"])
                instance.downloadDisabled = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["download_disabled"])
                instance.groupId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["group_id"])
                return instance
            }


            // Decoder for [ArticleVersions]
            Decoders.addDecoder(clazz: [ArticleVersions].self) { (source: AnyObject) -> [ArticleVersions] in
                return Decoders.decode(clazz: [ArticleVersions].self, source: source)
            }
            // Decoder for ArticleVersions
            Decoders.addDecoder(clazz: ArticleVersions.self) { (source: AnyObject) -> ArticleVersions in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ArticleVersions()
                instance.version = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["version"])
                instance.url = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url"])
                return instance
            }


            // Decoder for [ArticleWithProject]
            Decoders.addDecoder(clazz: [ArticleWithProject].self) { (source: AnyObject) -> [ArticleWithProject] in
                return Decoders.decode(clazz: [ArticleWithProject].self, source: source)
            }
            // Decoder for ArticleWithProject
            Decoders.addDecoder(clazz: ArticleWithProject.self) { (source: AnyObject) -> ArticleWithProject in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ArticleWithProject()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.title = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["title"])
                instance.doi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["doi"])
                instance.handle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["handle"])
                instance.url = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url"])
                instance.urlPublicHtml = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url_public_html"])
                instance.urlPublicApi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url_public_api"])
                instance.urlPrivateHtml = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url_private_html"])
                instance.urlPrivateApi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url_private_api"])
                instance.timeline = Decoders.decodeOptional(clazz: Timeline.self, source: sourceDictionary["timeline"])
                instance.thumb = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["thumb"])
                instance.definedType = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["defined_type"])
                instance.definedTypeName = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["defined_type_name"])
                instance.projectId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["project_id"])
                return instance
            }


            // Decoder for [ArticlesCreator]
            Decoders.addDecoder(clazz: [ArticlesCreator].self) { (source: AnyObject) -> [ArticlesCreator] in
                return Decoders.decode(clazz: [ArticlesCreator].self, source: source)
            }
            // Decoder for ArticlesCreator
            Decoders.addDecoder(clazz: ArticlesCreator.self) { (source: AnyObject) -> ArticlesCreator in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ArticlesCreator()
                instance.articles = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["articles"])
                return instance
            }


            // Decoder for [Author]
            Decoders.addDecoder(clazz: [Author].self) { (source: AnyObject) -> [Author] in
                return Decoders.decode(clazz: [Author].self, source: source)
            }
            // Decoder for Author
            Decoders.addDecoder(clazz: Author.self) { (source: AnyObject) -> Author in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = Author()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.fullName = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["full_name"])
                instance.isActive = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_active"])
                instance.urlName = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url_name"])
                instance.orcidId = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["orcid_id"])
                return instance
            }


            // Decoder for [AuthorComplete]
            Decoders.addDecoder(clazz: [AuthorComplete].self) { (source: AnyObject) -> [AuthorComplete] in
                return Decoders.decode(clazz: [AuthorComplete].self, source: source)
            }
            // Decoder for AuthorComplete
            Decoders.addDecoder(clazz: AuthorComplete.self) { (source: AnyObject) -> AuthorComplete in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = AuthorComplete()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.fullName = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["full_name"])
                instance.isActive = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_active"])
                instance.urlName = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url_name"])
                instance.orcidId = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["orcid_id"])
                instance.institutionId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["institution_id"])
                instance.groupId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["group_id"])
                instance.firstName = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["first_name"])
                instance.lastName = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["last_name"])
                instance.isPublic = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["is_public"])
                instance.jobTitle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["job_title"])
                return instance
            }


            // Decoder for [AuthorsCreator]
            Decoders.addDecoder(clazz: [AuthorsCreator].self) { (source: AnyObject) -> [AuthorsCreator] in
                return Decoders.decode(clazz: [AuthorsCreator].self, source: source)
            }
            // Decoder for AuthorsCreator
            Decoders.addDecoder(clazz: AuthorsCreator.self) { (source: AnyObject) -> AuthorsCreator in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = AuthorsCreator()
                instance.authors = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["authors"])
                return instance
            }


            // Decoder for [CategoriesCreator]
            Decoders.addDecoder(clazz: [CategoriesCreator].self) { (source: AnyObject) -> [CategoriesCreator] in
                return Decoders.decode(clazz: [CategoriesCreator].self, source: source)
            }
            // Decoder for CategoriesCreator
            Decoders.addDecoder(clazz: CategoriesCreator.self) { (source: AnyObject) -> CategoriesCreator in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = CategoriesCreator()
                instance.categories = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["categories"])
                return instance
            }


            // Decoder for [Category]
            Decoders.addDecoder(clazz: [Category].self) { (source: AnyObject) -> [Category] in
                return Decoders.decode(clazz: [Category].self, source: source)
            }
            // Decoder for Category
            Decoders.addDecoder(clazz: Category.self) { (source: AnyObject) -> Category in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = Category()
                instance.parentId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["parent_id"])
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.title = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["title"])
                instance.path = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["path"])
                instance.sourceId = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["source_id"])
                instance.taxonomyId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["taxonomy_id"])
                return instance
            }


            // Decoder for [Collaborator]
            Decoders.addDecoder(clazz: [Collaborator].self) { (source: AnyObject) -> [Collaborator] in
                return Decoders.decode(clazz: [Collaborator].self, source: source)
            }
            // Decoder for Collaborator
            Decoders.addDecoder(clazz: Collaborator.self) { (source: AnyObject) -> Collaborator in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = Collaborator()
                instance.roleName = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["role_name"])
                instance.userId = Decoders.decodeOptional(clazz: Int32.self, source: sourceDictionary["user_id"])
                instance.name = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["name"])
                return instance
            }


            // Decoder for [Collection]
            Decoders.addDecoder(clazz: [Collection].self) { (source: AnyObject) -> [Collection] in
                return Decoders.decode(clazz: [Collection].self, source: source)
            }
            // Decoder for Collection
            Decoders.addDecoder(clazz: Collection.self) { (source: AnyObject) -> Collection in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = Collection()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.title = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["title"])
                instance.doi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["doi"])
                instance.handle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["handle"])
                instance.url = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url"])
                instance.timeline = Decoders.decodeOptional(clazz: Timeline.self, source: sourceDictionary["timeline"])
                return instance
            }


            // Decoder for [CollectionComplete]
            Decoders.addDecoder(clazz: [CollectionComplete].self) { (source: AnyObject) -> [CollectionComplete] in
                return Decoders.decode(clazz: [CollectionComplete].self, source: source)
            }
            // Decoder for CollectionComplete
            Decoders.addDecoder(clazz: CollectionComplete.self) { (source: AnyObject) -> CollectionComplete in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = CollectionComplete()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.title = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["title"])
                instance.doi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["doi"])
                instance.handle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["handle"])
                instance.url = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url"])
                instance.timeline = Decoders.decodeOptional(clazz: Timeline.self, source: sourceDictionary["timeline"])
                instance.funding = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["funding"])
                instance.resourceId = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_id"])
                instance.resourceDoi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_doi"])
                instance.resourceTitle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_title"])
                instance.resourceLink = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_link"])
                instance.resourceVersion = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["resource_version"])
                instance.version = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["version"])
                instance.description = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["description"])
                instance.categories = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["categories"])
                instance.references = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["references"])
                instance.tags = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["tags"])
                instance.authors = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["authors"])
                instance.institutionId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["institution_id"])
                instance.groupId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["group_id"])
                instance.articlesCount = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["articles_count"])
                instance._public = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["public"])
                instance.citation = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["citation"])
                instance.customFields = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["custom_fields"])
                instance.modifiedDate = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["modified_date"])
                instance.createdDate = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["created_date"])
                return instance
            }


            // Decoder for [CollectionCompletePrivate]
            Decoders.addDecoder(clazz: [CollectionCompletePrivate].self) { (source: AnyObject) -> [CollectionCompletePrivate] in
                return Decoders.decode(clazz: [CollectionCompletePrivate].self, source: source)
            }
            // Decoder for CollectionCompletePrivate
            Decoders.addDecoder(clazz: CollectionCompletePrivate.self) { (source: AnyObject) -> CollectionCompletePrivate in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = CollectionCompletePrivate()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.title = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["title"])
                instance.doi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["doi"])
                instance.handle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["handle"])
                instance.url = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url"])
                instance.timeline = Decoders.decodeOptional(clazz: Timeline.self, source: sourceDictionary["timeline"])
                instance.accountId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["account_id"])
                instance.funding = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["funding"])
                instance.resourceId = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_id"])
                instance.resourceDoi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_doi"])
                instance.resourceTitle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_title"])
                instance.resourceLink = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_link"])
                instance.resourceVersion = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["resource_version"])
                instance.version = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["version"])
                instance.description = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["description"])
                instance.categories = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["categories"])
                instance.references = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["references"])
                instance.tags = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["tags"])
                instance.authors = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["authors"])
                instance.institutionId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["institution_id"])
                instance.groupId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["group_id"])
                instance.articlesCount = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["articles_count"])
                instance._public = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["public"])
                instance.citation = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["citation"])
                instance.customFields = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["custom_fields"])
                instance.modifiedDate = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["modified_date"])
                instance.createdDate = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["created_date"])
                return instance
            }


            // Decoder for [CollectionCreate]
            Decoders.addDecoder(clazz: [CollectionCreate].self) { (source: AnyObject) -> [CollectionCreate] in
                return Decoders.decode(clazz: [CollectionCreate].self, source: source)
            }
            // Decoder for CollectionCreate
            Decoders.addDecoder(clazz: CollectionCreate.self) { (source: AnyObject) -> CollectionCreate in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = CollectionCreate()
                instance.funding = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["funding"])
                instance.fundingList = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["funding_list"])
                instance.title = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["title"])
                instance.description = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["description"])
                instance.articles = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["articles"])
                instance.authors = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["authors"])
                instance.categories = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["categories"])
                instance.categoriesBySourceId = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["categories_by_source_id"])
                instance.tags = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["tags"])
                instance.keywords = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["keywords"])
                instance.references = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["references"])
                instance.customFields = Decoders.decodeOptional(clazz: AnyObject.self, source: sourceDictionary["custom_fields"])
                instance.customFieldsList = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["custom_fields_list"])
                instance.doi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["doi"])
                instance.handle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["handle"])
                instance.resourceId = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_id"])
                instance.resourceDoi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_doi"])
                instance.resourceLink = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_link"])
                instance.resourceTitle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_title"])
                instance.resourceVersion = Decoders.decodeOptional(clazz: Int32.self, source: sourceDictionary["resource_version"])
                instance.groupId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["group_id"])
                instance.timeline = Decoders.decodeOptional(clazz: TimelineUpdate.self, source: sourceDictionary["timeline"])
                return instance
            }


            // Decoder for [CollectionDOI]
            Decoders.addDecoder(clazz: [CollectionDOI].self) { (source: AnyObject) -> [CollectionDOI] in
                return Decoders.decode(clazz: [CollectionDOI].self, source: source)
            }
            // Decoder for CollectionDOI
            Decoders.addDecoder(clazz: CollectionDOI.self) { (source: AnyObject) -> CollectionDOI in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = CollectionDOI()
                instance.doi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["doi"])
                return instance
            }


            // Decoder for [CollectionHandle]
            Decoders.addDecoder(clazz: [CollectionHandle].self) { (source: AnyObject) -> [CollectionHandle] in
                return Decoders.decode(clazz: [CollectionHandle].self, source: source)
            }
            // Decoder for CollectionHandle
            Decoders.addDecoder(clazz: CollectionHandle.self) { (source: AnyObject) -> CollectionHandle in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = CollectionHandle()
                instance.handle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["handle"])
                return instance
            }


            // Decoder for [CollectionPrivateLinkCreator]
            Decoders.addDecoder(clazz: [CollectionPrivateLinkCreator].self) { (source: AnyObject) -> [CollectionPrivateLinkCreator] in
                return Decoders.decode(clazz: [CollectionPrivateLinkCreator].self, source: source)
            }
            // Decoder for CollectionPrivateLinkCreator
            Decoders.addDecoder(clazz: CollectionPrivateLinkCreator.self) { (source: AnyObject) -> CollectionPrivateLinkCreator in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = CollectionPrivateLinkCreator()
                instance.expiresDate = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["expires_date"])
                instance.readOnly = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["read_only"])
                return instance
            }


            // Decoder for [CollectionSearch]
            Decoders.addDecoder(clazz: [CollectionSearch].self) { (source: AnyObject) -> [CollectionSearch] in
                return Decoders.decode(clazz: [CollectionSearch].self, source: source)
            }
            // Decoder for CollectionSearch
            Decoders.addDecoder(clazz: CollectionSearch.self) { (source: AnyObject) -> CollectionSearch in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = CollectionSearch()
                instance.searchFor = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["search_for"])
                instance.page = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["page"])
                instance.pageSize = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["page_size"])
                instance.limit = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["limit"])
                instance.offset = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["offset"])
                instance.orderDirection = CollectionSearch.OrderDirection(rawValue: (sourceDictionary["order_direction"] as? String) ?? "") 
                instance.institution = Decoders.decodeOptional(clazz: Int32.self, source: sourceDictionary["institution"])
                instance.publishedSince = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["published_since"])
                instance.modifiedSince = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["modified_since"])
                instance.group = Decoders.decodeOptional(clazz: Int32.self, source: sourceDictionary["group"])
                instance.resourceDoi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_doi"])
                instance.doi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["doi"])
                instance.handle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["handle"])
                instance.order = CollectionSearch.Order(rawValue: (sourceDictionary["order"] as? String) ?? "") 
                return instance
            }


            // Decoder for [CollectionUpdate]
            Decoders.addDecoder(clazz: [CollectionUpdate].self) { (source: AnyObject) -> [CollectionUpdate] in
                return Decoders.decode(clazz: [CollectionUpdate].self, source: source)
            }
            // Decoder for CollectionUpdate
            Decoders.addDecoder(clazz: CollectionUpdate.self) { (source: AnyObject) -> CollectionUpdate in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = CollectionUpdate()
                instance.funding = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["funding"])
                instance.fundingList = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["funding_list"])
                instance.title = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["title"])
                instance.description = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["description"])
                instance.articles = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["articles"])
                instance.authors = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["authors"])
                instance.categories = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["categories"])
                instance.categoriesBySourceId = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["categories_by_source_id"])
                instance.tags = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["tags"])
                instance.keywords = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["keywords"])
                instance.references = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["references"])
                instance.customFields = Decoders.decodeOptional(clazz: AnyObject.self, source: sourceDictionary["custom_fields"])
                instance.customFieldsList = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["custom_fields_list"])
                instance.doi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["doi"])
                instance.handle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["handle"])
                instance.resourceId = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_id"])
                instance.resourceDoi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_doi"])
                instance.resourceLink = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_link"])
                instance.resourceTitle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_title"])
                instance.resourceVersion = Decoders.decodeOptional(clazz: Int32.self, source: sourceDictionary["resource_version"])
                instance.groupId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["group_id"])
                instance.timeline = Decoders.decodeOptional(clazz: TimelineUpdate.self, source: sourceDictionary["timeline"])
                return instance
            }


            // Decoder for [CollectionVersions]
            Decoders.addDecoder(clazz: [CollectionVersions].self) { (source: AnyObject) -> [CollectionVersions] in
                return Decoders.decode(clazz: [CollectionVersions].self, source: source)
            }
            // Decoder for CollectionVersions
            Decoders.addDecoder(clazz: CollectionVersions.self) { (source: AnyObject) -> CollectionVersions in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = CollectionVersions()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.url = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url"])
                return instance
            }


            // Decoder for [CommonSearch]
            Decoders.addDecoder(clazz: [CommonSearch].self) { (source: AnyObject) -> [CommonSearch] in
                return Decoders.decode(clazz: [CommonSearch].self, source: source)
            }
            // Decoder for CommonSearch
            Decoders.addDecoder(clazz: CommonSearch.self) { (source: AnyObject) -> CommonSearch in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = CommonSearch()
                instance.searchFor = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["search_for"])
                instance.page = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["page"])
                instance.pageSize = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["page_size"])
                instance.limit = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["limit"])
                instance.offset = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["offset"])
                instance.orderDirection = CommonSearch.OrderDirection(rawValue: (sourceDictionary["order_direction"] as? String) ?? "") 
                instance.institution = Decoders.decodeOptional(clazz: Int32.self, source: sourceDictionary["institution"])
                instance.publishedSince = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["published_since"])
                instance.modifiedSince = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["modified_since"])
                instance.group = Decoders.decodeOptional(clazz: Int32.self, source: sourceDictionary["group"])
                return instance
            }


            // Decoder for [ConfidentialityCreator]
            Decoders.addDecoder(clazz: [ConfidentialityCreator].self) { (source: AnyObject) -> [ConfidentialityCreator] in
                return Decoders.decode(clazz: [ConfidentialityCreator].self, source: source)
            }
            // Decoder for ConfidentialityCreator
            Decoders.addDecoder(clazz: ConfidentialityCreator.self) { (source: AnyObject) -> ConfidentialityCreator in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ConfidentialityCreator()
                instance.reason = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["reason"])
                return instance
            }


            // Decoder for [CreateProjectResponse]
            Decoders.addDecoder(clazz: [CreateProjectResponse].self) { (source: AnyObject) -> [CreateProjectResponse] in
                return Decoders.decode(clazz: [CreateProjectResponse].self, source: source)
            }
            // Decoder for CreateProjectResponse
            Decoders.addDecoder(clazz: CreateProjectResponse.self) { (source: AnyObject) -> CreateProjectResponse in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = CreateProjectResponse()
                instance.entityId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["entity_id"])
                instance.location = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["location"])
                return instance
            }


            // Decoder for [Curation]
            Decoders.addDecoder(clazz: [Curation].self) { (source: AnyObject) -> [Curation] in
                return Decoders.decode(clazz: [Curation].self, source: source)
            }
            // Decoder for Curation
            Decoders.addDecoder(clazz: Curation.self) { (source: AnyObject) -> Curation in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = Curation()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.groupId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["group_id"])
                instance.accountId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["account_id"])
                instance.assignedTo = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["assigned_to"])
                instance.articleId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["article_id"])
                instance.version = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["version"])
                instance.commentsCount = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["comments_count"])
                instance.status = Curation.Status(rawValue: (sourceDictionary["status"] as? String) ?? "") 
                instance.createdDate = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["created_date"])
                instance.modifiedDate = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["modified_date"])
                return instance
            }


            // Decoder for [CurationComment]
            Decoders.addDecoder(clazz: [CurationComment].self) { (source: AnyObject) -> [CurationComment] in
                return Decoders.decode(clazz: [CurationComment].self, source: source)
            }
            // Decoder for CurationComment
            Decoders.addDecoder(clazz: CurationComment.self) { (source: AnyObject) -> CurationComment in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = CurationComment()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.accountId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["account_id"])
                instance.type = CurationComment.ModelType(rawValue: (sourceDictionary["type"] as? String) ?? "") 
                instance.text = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["text"])
                return instance
            }


            // Decoder for [CurationCommentCreate]
            Decoders.addDecoder(clazz: [CurationCommentCreate].self) { (source: AnyObject) -> [CurationCommentCreate] in
                return Decoders.decode(clazz: [CurationCommentCreate].self, source: source)
            }
            // Decoder for CurationCommentCreate
            Decoders.addDecoder(clazz: CurationCommentCreate.self) { (source: AnyObject) -> CurationCommentCreate in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = CurationCommentCreate()
                instance.text = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["text"])
                return instance
            }


            // Decoder for [CurationDetail]
            Decoders.addDecoder(clazz: [CurationDetail].self) { (source: AnyObject) -> [CurationDetail] in
                return Decoders.decode(clazz: [CurationDetail].self, source: source)
            }
            // Decoder for CurationDetail
            Decoders.addDecoder(clazz: CurationDetail.self) { (source: AnyObject) -> CurationDetail in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = CurationDetail()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.groupId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["group_id"])
                instance.accountId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["account_id"])
                instance.assignedTo = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["assigned_to"])
                instance.articleId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["article_id"])
                instance.version = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["version"])
                instance.commentsCount = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["comments_count"])
                instance.status = CurationDetail.Status(rawValue: (sourceDictionary["status"] as? String) ?? "") 
                instance.createdDate = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["created_date"])
                instance.modifiedDate = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["modified_date"])
                instance.item = Decoders.decodeOptional(clazz: ArticleComplete.self, source: sourceDictionary["item"])
                return instance
            }


            // Decoder for [CustomArticleField]
            Decoders.addDecoder(clazz: [CustomArticleField].self) { (source: AnyObject) -> [CustomArticleField] in
                return Decoders.decode(clazz: [CustomArticleField].self, source: source)
            }
            // Decoder for CustomArticleField
            Decoders.addDecoder(clazz: CustomArticleField.self) { (source: AnyObject) -> CustomArticleField in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = CustomArticleField()
                instance.name = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["name"])
                instance.value = Decoders.decodeOptional(clazz: AnyObject.self, source: sourceDictionary["value"])
                return instance
            }


            // Decoder for [CustomArticleFieldAdd]
            Decoders.addDecoder(clazz: [CustomArticleFieldAdd].self) { (source: AnyObject) -> [CustomArticleFieldAdd] in
                return Decoders.decode(clazz: [CustomArticleFieldAdd].self, source: source)
            }
            // Decoder for CustomArticleFieldAdd
            Decoders.addDecoder(clazz: CustomArticleFieldAdd.self) { (source: AnyObject) -> CustomArticleFieldAdd in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = CustomArticleFieldAdd()
                instance.name = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["name"])
                instance.value = Decoders.decodeOptional(clazz: AnyObject.self, source: sourceDictionary["value"])
                return instance
            }


            // Decoder for [ErrorMessage]
            Decoders.addDecoder(clazz: [ErrorMessage].self) { (source: AnyObject) -> [ErrorMessage] in
                return Decoders.decode(clazz: [ErrorMessage].self, source: source)
            }
            // Decoder for ErrorMessage
            Decoders.addDecoder(clazz: ErrorMessage.self) { (source: AnyObject) -> ErrorMessage in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ErrorMessage()
                instance.code = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["code"])
                instance.message = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["message"])
                return instance
            }


            // Decoder for [FileCreator]
            Decoders.addDecoder(clazz: [FileCreator].self) { (source: AnyObject) -> [FileCreator] in
                return Decoders.decode(clazz: [FileCreator].self, source: source)
            }
            // Decoder for FileCreator
            Decoders.addDecoder(clazz: FileCreator.self) { (source: AnyObject) -> FileCreator in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = FileCreator()
                instance.link = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["link"])
                instance.md5 = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["md5"])
                instance.name = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["name"])
                instance.size = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["size"])
                instance.folderPath = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["folder_path"])
                return instance
            }


            // Decoder for [FileId]
            Decoders.addDecoder(clazz: [FileId].self) { (source: AnyObject) -> [FileId] in
                return Decoders.decode(clazz: [FileId].self, source: source)
            }
            // Decoder for FileId
            Decoders.addDecoder(clazz: FileId.self) { (source: AnyObject) -> FileId in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = FileId()
                instance.fileId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["file_id"])
                return instance
            }


            // Decoder for [FundingCreate]
            Decoders.addDecoder(clazz: [FundingCreate].self) { (source: AnyObject) -> [FundingCreate] in
                return Decoders.decode(clazz: [FundingCreate].self, source: source)
            }
            // Decoder for FundingCreate
            Decoders.addDecoder(clazz: FundingCreate.self) { (source: AnyObject) -> FundingCreate in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = FundingCreate()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.title = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["title"])
                return instance
            }


            // Decoder for [FundingInformation]
            Decoders.addDecoder(clazz: [FundingInformation].self) { (source: AnyObject) -> [FundingInformation] in
                return Decoders.decode(clazz: [FundingInformation].self, source: source)
            }
            // Decoder for FundingInformation
            Decoders.addDecoder(clazz: FundingInformation.self) { (source: AnyObject) -> FundingInformation in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = FundingInformation()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.title = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["title"])
                instance.grantCode = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["grant_code"])
                instance.funderName = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["funder_name"])
                instance.isUserDefined = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["is_user_defined"])
                instance.url = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url"])
                return instance
            }


            // Decoder for [FundingSearch]
            Decoders.addDecoder(clazz: [FundingSearch].self) { (source: AnyObject) -> [FundingSearch] in
                return Decoders.decode(clazz: [FundingSearch].self, source: source)
            }
            // Decoder for FundingSearch
            Decoders.addDecoder(clazz: FundingSearch.self) { (source: AnyObject) -> FundingSearch in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = FundingSearch()
                instance.searchFor = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["search_for"])
                return instance
            }


            // Decoder for [Group]
            Decoders.addDecoder(clazz: [Group].self) { (source: AnyObject) -> [Group] in
                return Decoders.decode(clazz: [Group].self, source: source)
            }
            // Decoder for Group
            Decoders.addDecoder(clazz: Group.self) { (source: AnyObject) -> Group in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = Group()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.name = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["name"])
                instance.resourceId = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_id"])
                instance.parentId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["parent_id"])
                instance.associationCriteria = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["association_criteria"])
                return instance
            }


            // Decoder for [GroupEmbargoOptions]
            Decoders.addDecoder(clazz: [GroupEmbargoOptions].self) { (source: AnyObject) -> [GroupEmbargoOptions] in
                return Decoders.decode(clazz: [GroupEmbargoOptions].self, source: source)
            }
            // Decoder for GroupEmbargoOptions
            Decoders.addDecoder(clazz: GroupEmbargoOptions.self) { (source: AnyObject) -> GroupEmbargoOptions in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = GroupEmbargoOptions()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.type = GroupEmbargoOptions.ModelType(rawValue: (sourceDictionary["type"] as? String) ?? "") 
                instance.ipName = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["ip_name"])
                return instance
            }


            // Decoder for [Institution]
            Decoders.addDecoder(clazz: [Institution].self) { (source: AnyObject) -> [Institution] in
                return Decoders.decode(clazz: [Institution].self, source: source)
            }
            // Decoder for Institution
            Decoders.addDecoder(clazz: Institution.self) { (source: AnyObject) -> Institution in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = Institution()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.name = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["name"])
                return instance
            }


            // Decoder for [InstitutionAccountsSearch]
            Decoders.addDecoder(clazz: [InstitutionAccountsSearch].self) { (source: AnyObject) -> [InstitutionAccountsSearch] in
                return Decoders.decode(clazz: [InstitutionAccountsSearch].self, source: source)
            }
            // Decoder for InstitutionAccountsSearch
            Decoders.addDecoder(clazz: InstitutionAccountsSearch.self) { (source: AnyObject) -> InstitutionAccountsSearch in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = InstitutionAccountsSearch()
                instance.searchFor = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["search_for"])
                instance.isActive = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["is_active"])
                instance.page = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["page"])
                instance.pageSize = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["page_size"])
                instance.limit = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["limit"])
                instance.offset = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["offset"])
                instance.institutionUserId = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["institution_user_id"])
                instance.email = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["email"])
                return instance
            }


            // Decoder for [ItemType]
            Decoders.addDecoder(clazz: [ItemType].self) { (source: AnyObject) -> [ItemType] in
                return Decoders.decode(clazz: [ItemType].self, source: source)
            }
            // Decoder for ItemType
            Decoders.addDecoder(clazz: ItemType.self) { (source: AnyObject) -> ItemType in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ItemType()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.name = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["name"])
                instance.stringId = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["string_id"])
                instance.icon = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["icon"])
                instance.publicDescription = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["public_description"])
                instance.isSelectable = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_selectable"])
                instance.urlName = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url_name"])
                return instance
            }


            // Decoder for [License]
            Decoders.addDecoder(clazz: [License].self) { (source: AnyObject) -> [License] in
                return Decoders.decode(clazz: [License].self, source: source)
            }
            // Decoder for License
            Decoders.addDecoder(clazz: License.self) { (source: AnyObject) -> License in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = License()
                instance.value = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["value"])
                instance.name = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["name"])
                instance.url = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url"])
                return instance
            }


            // Decoder for [Location]
            Decoders.addDecoder(clazz: [Location].self) { (source: AnyObject) -> [Location] in
                return Decoders.decode(clazz: [Location].self, source: source)
            }
            // Decoder for Location
            Decoders.addDecoder(clazz: Location.self) { (source: AnyObject) -> Location in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = Location()
                instance.location = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["location"])
                return instance
            }


            // Decoder for [LocationWarnings]
            Decoders.addDecoder(clazz: [LocationWarnings].self) { (source: AnyObject) -> [LocationWarnings] in
                return Decoders.decode(clazz: [LocationWarnings].self, source: source)
            }
            // Decoder for LocationWarnings
            Decoders.addDecoder(clazz: LocationWarnings.self) { (source: AnyObject) -> LocationWarnings in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = LocationWarnings()
                instance.entityId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["entity_id"])
                instance.location = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["location"])
                instance.warnings = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["warnings"])
                return instance
            }


            // Decoder for [LocationWarningsUpdate]
            Decoders.addDecoder(clazz: [LocationWarningsUpdate].self) { (source: AnyObject) -> [LocationWarningsUpdate] in
                return Decoders.decode(clazz: [LocationWarningsUpdate].self, source: source)
            }
            // Decoder for LocationWarningsUpdate
            Decoders.addDecoder(clazz: LocationWarningsUpdate.self) { (source: AnyObject) -> LocationWarningsUpdate in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = LocationWarningsUpdate()
                instance.location = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["location"])
                instance.warnings = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["warnings"])
                return instance
            }


            // Decoder for [PrivateArticleSearch]
            Decoders.addDecoder(clazz: [PrivateArticleSearch].self) { (source: AnyObject) -> [PrivateArticleSearch] in
                return Decoders.decode(clazz: [PrivateArticleSearch].self, source: source)
            }
            // Decoder for PrivateArticleSearch
            Decoders.addDecoder(clazz: PrivateArticleSearch.self) { (source: AnyObject) -> PrivateArticleSearch in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = PrivateArticleSearch()
                instance.resourceDoi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_doi"])
                instance.itemType = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["item_type"])
                instance.doi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["doi"])
                instance.handle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["handle"])
                instance.projectId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["project_id"])
                instance.order = PrivateArticleSearch.Order(rawValue: (sourceDictionary["order"] as? String) ?? "") 
                instance.searchFor = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["search_for"])
                instance.page = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["page"])
                instance.pageSize = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["page_size"])
                instance.limit = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["limit"])
                instance.offset = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["offset"])
                instance.orderDirection = PrivateArticleSearch.OrderDirection(rawValue: (sourceDictionary["order_direction"] as? String) ?? "") 
                instance.institution = Decoders.decodeOptional(clazz: Int32.self, source: sourceDictionary["institution"])
                instance.publishedSince = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["published_since"])
                instance.modifiedSince = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["modified_since"])
                instance.group = Decoders.decodeOptional(clazz: Int32.self, source: sourceDictionary["group"])
                instance.resourceId = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_id"])
                return instance
            }


            // Decoder for [PrivateAuthorsSearch]
            Decoders.addDecoder(clazz: [PrivateAuthorsSearch].self) { (source: AnyObject) -> [PrivateAuthorsSearch] in
                return Decoders.decode(clazz: [PrivateAuthorsSearch].self, source: source)
            }
            // Decoder for PrivateAuthorsSearch
            Decoders.addDecoder(clazz: PrivateAuthorsSearch.self) { (source: AnyObject) -> PrivateAuthorsSearch in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = PrivateAuthorsSearch()
                instance.searchFor = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["search_for"])
                instance.page = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["page"])
                instance.pageSize = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["page_size"])
                instance.limit = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["limit"])
                instance.offset = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["offset"])
                instance.order = PrivateAuthorsSearch.Order(rawValue: (sourceDictionary["order"] as? String) ?? "") 
                instance.orderDirection = PrivateAuthorsSearch.OrderDirection(rawValue: (sourceDictionary["order_direction"] as? String) ?? "") 
                instance.institutionId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["institution_id"])
                instance.orcid = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["orcid"])
                instance.groupId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["group_id"])
                instance.isActive = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_active"])
                instance.isPublic = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_public"])
                return instance
            }


            // Decoder for [PrivateCollectionSearch]
            Decoders.addDecoder(clazz: [PrivateCollectionSearch].self) { (source: AnyObject) -> [PrivateCollectionSearch] in
                return Decoders.decode(clazz: [PrivateCollectionSearch].self, source: source)
            }
            // Decoder for PrivateCollectionSearch
            Decoders.addDecoder(clazz: PrivateCollectionSearch.self) { (source: AnyObject) -> PrivateCollectionSearch in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = PrivateCollectionSearch()
                instance.resourceDoi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_doi"])
                instance.doi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["doi"])
                instance.handle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["handle"])
                instance.order = PrivateCollectionSearch.Order(rawValue: (sourceDictionary["order"] as? String) ?? "") 
                instance.searchFor = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["search_for"])
                instance.page = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["page"])
                instance.pageSize = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["page_size"])
                instance.limit = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["limit"])
                instance.offset = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["offset"])
                instance.orderDirection = PrivateCollectionSearch.OrderDirection(rawValue: (sourceDictionary["order_direction"] as? String) ?? "") 
                instance.institution = Decoders.decodeOptional(clazz: Int32.self, source: sourceDictionary["institution"])
                instance.publishedSince = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["published_since"])
                instance.modifiedSince = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["modified_since"])
                instance.group = Decoders.decodeOptional(clazz: Int32.self, source: sourceDictionary["group"])
                instance.resourceId = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["resource_id"])
                return instance
            }


            // Decoder for [PrivateFile]
            Decoders.addDecoder(clazz: [PrivateFile].self) { (source: AnyObject) -> [PrivateFile] in
                return Decoders.decode(clazz: [PrivateFile].self, source: source)
            }
            // Decoder for PrivateFile
            Decoders.addDecoder(clazz: PrivateFile.self) { (source: AnyObject) -> PrivateFile in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = PrivateFile()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.name = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["name"])
                instance.size = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["size"])
                instance.isLinkOnly = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_link_only"])
                instance.downloadUrl = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["download_url"])
                instance.suppliedMd5 = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["supplied_md5"])
                instance.computedMd5 = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["computed_md5"])
                instance.mimetype = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["mimetype"])
                instance.viewerType = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["viewer_type"])
                instance.previewState = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["preview_state"])
                instance.uploadUrl = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["upload_url"])
                instance.uploadToken = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["upload_token"])
                instance.isAttachedToPublicVersion = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_attached_to_public_version"])
                return instance
            }


            // Decoder for [PrivateLink]
            Decoders.addDecoder(clazz: [PrivateLink].self) { (source: AnyObject) -> [PrivateLink] in
                return Decoders.decode(clazz: [PrivateLink].self, source: source)
            }
            // Decoder for PrivateLink
            Decoders.addDecoder(clazz: PrivateLink.self) { (source: AnyObject) -> PrivateLink in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = PrivateLink()
                instance.id = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["id"])
                instance.isActive = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_active"])
                instance.expiresDate = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["expires_date"])
                instance.htmlLocation = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["html_location"])
                return instance
            }


            // Decoder for [PrivateLinkCreator]
            Decoders.addDecoder(clazz: [PrivateLinkCreator].self) { (source: AnyObject) -> [PrivateLinkCreator] in
                return Decoders.decode(clazz: [PrivateLinkCreator].self, source: source)
            }
            // Decoder for PrivateLinkCreator
            Decoders.addDecoder(clazz: PrivateLinkCreator.self) { (source: AnyObject) -> PrivateLinkCreator in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = PrivateLinkCreator()
                instance.expiresDate = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["expires_date"])
                instance.readOnly = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["read_only"])
                return instance
            }


            // Decoder for [PrivateLinkResponse]
            Decoders.addDecoder(clazz: [PrivateLinkResponse].self) { (source: AnyObject) -> [PrivateLinkResponse] in
                return Decoders.decode(clazz: [PrivateLinkResponse].self, source: source)
            }
            // Decoder for PrivateLinkResponse
            Decoders.addDecoder(clazz: PrivateLinkResponse.self) { (source: AnyObject) -> PrivateLinkResponse in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = PrivateLinkResponse()
                instance.location = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["location"])
                instance.htmlLocation = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["html_location"])
                instance.token = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["token"])
                return instance
            }


            // Decoder for [Project]
            Decoders.addDecoder(clazz: [Project].self) { (source: AnyObject) -> [Project] in
                return Decoders.decode(clazz: [Project].self, source: source)
            }
            // Decoder for Project
            Decoders.addDecoder(clazz: Project.self) { (source: AnyObject) -> Project in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = Project()
                instance.url = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url"])
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.title = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["title"])
                return instance
            }


            // Decoder for [ProjectArticle]
            Decoders.addDecoder(clazz: [ProjectArticle].self) { (source: AnyObject) -> [ProjectArticle] in
                return Decoders.decode(clazz: [ProjectArticle].self, source: source)
            }
            // Decoder for ProjectArticle
            Decoders.addDecoder(clazz: ProjectArticle.self) { (source: AnyObject) -> ProjectArticle in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ProjectArticle()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.title = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["title"])
                instance.doi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["doi"])
                instance.handle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["handle"])
                instance.url = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url"])
                instance.urlPublicHtml = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url_public_html"])
                instance.urlPublicApi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url_public_api"])
                instance.urlPrivateHtml = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url_private_html"])
                instance.urlPrivateApi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url_private_api"])
                instance.timeline = Decoders.decodeOptional(clazz: Timeline.self, source: sourceDictionary["timeline"])
                instance.thumb = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["thumb"])
                instance.definedType = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["defined_type"])
                instance.definedTypeName = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["defined_type_name"])
                instance.citation = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["citation"])
                instance.confidentialReason = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["confidential_reason"])
                instance.isConfidential = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_confidential"])
                instance.size = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["size"])
                instance.funding = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["funding"])
                instance.fundingList = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["funding_list"])
                instance.tags = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["tags"])
                instance.version = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["version"])
                instance.isActive = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_active"])
                instance.isMetadataRecord = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_metadata_record"])
                instance.metadataReason = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["metadata_reason"])
                instance.status = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["status"])
                instance.description = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["description"])
                instance.isEmbargoed = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_embargoed"])
                instance.isPublic = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_public"])
                instance.createdDate = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["created_date"])
                instance.hasLinkedFile = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["has_linked_file"])
                instance.categories = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["categories"])
                instance.license = Decoders.decodeOptional(clazz: License.self, source: sourceDictionary["license"])
                instance.embargoTitle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["embargo_title"])
                instance.embargoReason = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["embargo_reason"])
                instance.references = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["references"])
                instance.relatedMaterials = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["related_materials"])
                return instance
            }


            // Decoder for [ProjectCollaborator]
            Decoders.addDecoder(clazz: [ProjectCollaborator].self) { (source: AnyObject) -> [ProjectCollaborator] in
                return Decoders.decode(clazz: [ProjectCollaborator].self, source: source)
            }
            // Decoder for ProjectCollaborator
            Decoders.addDecoder(clazz: ProjectCollaborator.self) { (source: AnyObject) -> ProjectCollaborator in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ProjectCollaborator()
                instance.status = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["status"])
                instance.roleName = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["role_name"])
                instance.userId = Decoders.decodeOptional(clazz: Int32.self, source: sourceDictionary["user_id"])
                instance.name = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["name"])
                return instance
            }


            // Decoder for [ProjectCollaboratorInvite]
            Decoders.addDecoder(clazz: [ProjectCollaboratorInvite].self) { (source: AnyObject) -> [ProjectCollaboratorInvite] in
                return Decoders.decode(clazz: [ProjectCollaboratorInvite].self, source: source)
            }
            // Decoder for ProjectCollaboratorInvite
            Decoders.addDecoder(clazz: ProjectCollaboratorInvite.self) { (source: AnyObject) -> ProjectCollaboratorInvite in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ProjectCollaboratorInvite()
                instance.roleName = ProjectCollaboratorInvite.RoleName(rawValue: (sourceDictionary["role_name"] as? String) ?? "") 
                instance.userId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["user_id"])
                instance.email = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["email"])
                instance.comment = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["comment"])
                return instance
            }


            // Decoder for [ProjectComplete]
            Decoders.addDecoder(clazz: [ProjectComplete].self) { (source: AnyObject) -> [ProjectComplete] in
                return Decoders.decode(clazz: [ProjectComplete].self, source: source)
            }
            // Decoder for ProjectComplete
            Decoders.addDecoder(clazz: ProjectComplete.self) { (source: AnyObject) -> ProjectComplete in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ProjectComplete()
                instance.url = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url"])
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.title = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["title"])
                instance.funding = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["funding"])
                instance.fundingList = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["funding_list"])
                instance.description = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["description"])
                instance.collaborators = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["collaborators"])
                return instance
            }


            // Decoder for [ProjectCompletePrivate]
            Decoders.addDecoder(clazz: [ProjectCompletePrivate].self) { (source: AnyObject) -> [ProjectCompletePrivate] in
                return Decoders.decode(clazz: [ProjectCompletePrivate].self, source: source)
            }
            // Decoder for ProjectCompletePrivate
            Decoders.addDecoder(clazz: ProjectCompletePrivate.self) { (source: AnyObject) -> ProjectCompletePrivate in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ProjectCompletePrivate()
                instance.role = ProjectCompletePrivate.Role(rawValue: (sourceDictionary["role"] as? String) ?? "") 
                instance.storage = ProjectCompletePrivate.Storage(rawValue: (sourceDictionary["storage"] as? String) ?? "") 
                instance.url = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url"])
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.title = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["title"])
                instance.funding = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["funding"])
                instance.fundingList = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["funding_list"])
                instance.description = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["description"])
                instance.collaborators = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["collaborators"])
                instance.quota = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["quota"])
                instance.usedQuota = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["used_quota"])
                instance.createdDate = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["created_date"])
                instance.modifiedDate = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["modified_date"])
                instance.usedQuotaPrivate = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["used_quota_private"])
                instance.usedQuotaPublic = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["used_quota_public"])
                instance.groupId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["group_id"])
                instance.accountId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["account_id"])
                instance.customFields = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["custom_fields"])
                return instance
            }


            // Decoder for [ProjectCreate]
            Decoders.addDecoder(clazz: [ProjectCreate].self) { (source: AnyObject) -> [ProjectCreate] in
                return Decoders.decode(clazz: [ProjectCreate].self, source: source)
            }
            // Decoder for ProjectCreate
            Decoders.addDecoder(clazz: ProjectCreate.self) { (source: AnyObject) -> ProjectCreate in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ProjectCreate()
                instance.title = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["title"])
                instance.description = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["description"])
                instance.funding = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["funding"])
                instance.fundingList = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["funding_list"])
                instance.groupId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["group_id"])
                instance.customFields = Decoders.decodeOptional(clazz: AnyObject.self, source: sourceDictionary["custom_fields"])
                instance.customFieldsList = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["custom_fields_list"])
                return instance
            }


            // Decoder for [ProjectNote]
            Decoders.addDecoder(clazz: [ProjectNote].self) { (source: AnyObject) -> [ProjectNote] in
                return Decoders.decode(clazz: [ProjectNote].self, source: source)
            }
            // Decoder for ProjectNote
            Decoders.addDecoder(clazz: ProjectNote.self) { (source: AnyObject) -> ProjectNote in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ProjectNote()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.userId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["user_id"])
                instance.abstract = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["abstract"])
                instance.userName = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["user_name"])
                instance.createdDate = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["created_date"])
                instance.modifiedDate = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["modified_date"])
                return instance
            }


            // Decoder for [ProjectNoteCreate]
            Decoders.addDecoder(clazz: [ProjectNoteCreate].self) { (source: AnyObject) -> [ProjectNoteCreate] in
                return Decoders.decode(clazz: [ProjectNoteCreate].self, source: source)
            }
            // Decoder for ProjectNoteCreate
            Decoders.addDecoder(clazz: ProjectNoteCreate.self) { (source: AnyObject) -> ProjectNoteCreate in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ProjectNoteCreate()
                instance.text = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["text"])
                return instance
            }


            // Decoder for [ProjectNotePrivate]
            Decoders.addDecoder(clazz: [ProjectNotePrivate].self) { (source: AnyObject) -> [ProjectNotePrivate] in
                return Decoders.decode(clazz: [ProjectNotePrivate].self, source: source)
            }
            // Decoder for ProjectNotePrivate
            Decoders.addDecoder(clazz: ProjectNotePrivate.self) { (source: AnyObject) -> ProjectNotePrivate in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ProjectNotePrivate()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.userId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["user_id"])
                instance.abstract = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["abstract"])
                instance.userName = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["user_name"])
                instance.createdDate = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["created_date"])
                instance.modifiedDate = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["modified_date"])
                instance.text = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["text"])
                return instance
            }


            // Decoder for [ProjectPrivate]
            Decoders.addDecoder(clazz: [ProjectPrivate].self) { (source: AnyObject) -> [ProjectPrivate] in
                return Decoders.decode(clazz: [ProjectPrivate].self, source: source)
            }
            // Decoder for ProjectPrivate
            Decoders.addDecoder(clazz: ProjectPrivate.self) { (source: AnyObject) -> ProjectPrivate in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ProjectPrivate()
                instance.url = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url"])
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.title = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["title"])
                instance.role = ProjectPrivate.Role(rawValue: (sourceDictionary["role"] as? String) ?? "") 
                instance.storage = ProjectPrivate.Storage(rawValue: (sourceDictionary["storage"] as? String) ?? "") 
                return instance
            }


            // Decoder for [ProjectUpdate]
            Decoders.addDecoder(clazz: [ProjectUpdate].self) { (source: AnyObject) -> [ProjectUpdate] in
                return Decoders.decode(clazz: [ProjectUpdate].self, source: source)
            }
            // Decoder for ProjectUpdate
            Decoders.addDecoder(clazz: ProjectUpdate.self) { (source: AnyObject) -> ProjectUpdate in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ProjectUpdate()
                instance.title = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["title"])
                instance.description = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["description"])
                instance.funding = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["funding"])
                instance.fundingList = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["funding_list"])
                instance.customFields = Decoders.decodeOptional(clazz: AnyObject.self, source: sourceDictionary["custom_fields"])
                instance.customFieldsList = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["custom_fields_list"])
                return instance
            }


            // Decoder for [ProjectsSearch]
            Decoders.addDecoder(clazz: [ProjectsSearch].self) { (source: AnyObject) -> [ProjectsSearch] in
                return Decoders.decode(clazz: [ProjectsSearch].self, source: source)
            }
            // Decoder for ProjectsSearch
            Decoders.addDecoder(clazz: ProjectsSearch.self) { (source: AnyObject) -> ProjectsSearch in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ProjectsSearch()
                instance.searchFor = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["search_for"])
                instance.page = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["page"])
                instance.pageSize = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["page_size"])
                instance.limit = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["limit"])
                instance.offset = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["offset"])
                instance.orderDirection = ProjectsSearch.OrderDirection(rawValue: (sourceDictionary["order_direction"] as? String) ?? "") 
                instance.institution = Decoders.decodeOptional(clazz: Int32.self, source: sourceDictionary["institution"])
                instance.publishedSince = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["published_since"])
                instance.modifiedSince = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["modified_since"])
                instance.group = Decoders.decodeOptional(clazz: Int32.self, source: sourceDictionary["group"])
                instance.order = ProjectsSearch.Order(rawValue: (sourceDictionary["order"] as? String) ?? "") 
                return instance
            }


            // Decoder for [PublicFile]
            Decoders.addDecoder(clazz: [PublicFile].self) { (source: AnyObject) -> [PublicFile] in
                return Decoders.decode(clazz: [PublicFile].self, source: source)
            }
            // Decoder for PublicFile
            Decoders.addDecoder(clazz: PublicFile.self) { (source: AnyObject) -> PublicFile in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = PublicFile()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.name = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["name"])
                instance.size = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["size"])
                instance.isLinkOnly = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_link_only"])
                instance.downloadUrl = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["download_url"])
                instance.suppliedMd5 = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["supplied_md5"])
                instance.computedMd5 = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["computed_md5"])
                instance.mimetype = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["mimetype"])
                return instance
            }


            // Decoder for [RelatedMaterial]
            Decoders.addDecoder(clazz: [RelatedMaterial].self) { (source: AnyObject) -> [RelatedMaterial] in
                return Decoders.decode(clazz: [RelatedMaterial].self, source: source)
            }
            // Decoder for RelatedMaterial
            Decoders.addDecoder(clazz: RelatedMaterial.self) { (source: AnyObject) -> RelatedMaterial in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = RelatedMaterial()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.identifier = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["identifier"])
                instance.title = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["title"])
                instance.relation = RelatedMaterial.Relation(rawValue: (sourceDictionary["relation"] as? String) ?? "") 
                instance.identifierType = RelatedMaterial.IdentifierType(rawValue: (sourceDictionary["identifier_type"] as? String) ?? "") 
                instance.isLinkout = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_linkout"])
                instance.link = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["link"])
                return instance
            }


            // Decoder for [Resource]
            Decoders.addDecoder(clazz: [Resource].self) { (source: AnyObject) -> [Resource] in
                return Decoders.decode(clazz: [Resource].self, source: source)
            }
            // Decoder for Resource
            Decoders.addDecoder(clazz: Resource.self) { (source: AnyObject) -> Resource in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = Resource()
                instance.id = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["id"])
                instance.title = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["title"])
                instance.doi = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["doi"])
                instance.link = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["link"])
                instance.status = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["status"])
                instance.version = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["version"])
                return instance
            }


            // Decoder for [ResponseMessage]
            Decoders.addDecoder(clazz: [ResponseMessage].self) { (source: AnyObject) -> [ResponseMessage] in
                return Decoders.decode(clazz: [ResponseMessage].self, source: source)
            }
            // Decoder for ResponseMessage
            Decoders.addDecoder(clazz: ResponseMessage.self) { (source: AnyObject) -> ResponseMessage in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ResponseMessage()
                instance.message = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["message"])
                return instance
            }


            // Decoder for [Role]
            Decoders.addDecoder(clazz: [Role].self) { (source: AnyObject) -> [Role] in
                return Decoders.decode(clazz: [Role].self, source: source)
            }
            // Decoder for Role
            Decoders.addDecoder(clazz: Role.self) { (source: AnyObject) -> Role in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = Role()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.name = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["name"])
                instance.category = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["category"])
                instance.description = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["description"])
                return instance
            }


            // Decoder for [ShortAccount]
            Decoders.addDecoder(clazz: [ShortAccount].self) { (source: AnyObject) -> [ShortAccount] in
                return Decoders.decode(clazz: [ShortAccount].self, source: source)
            }
            // Decoder for ShortAccount
            Decoders.addDecoder(clazz: ShortAccount.self) { (source: AnyObject) -> ShortAccount in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ShortAccount()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.firstName = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["first_name"])
                instance.lastName = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["last_name"])
                instance.institutionId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["institution_id"])
                instance.email = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["email"])
                instance.active = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["active"])
                instance.institutionUserId = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["institution_user_id"])
                instance.quota = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["quota"])
                instance.usedQuota = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["used_quota"])
                instance.userId = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["user_id"])
                instance.orcidId = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["orcid_id"])
                return instance
            }


            // Decoder for [ShortCustomField]
            Decoders.addDecoder(clazz: [ShortCustomField].self) { (source: AnyObject) -> [ShortCustomField] in
                return Decoders.decode(clazz: [ShortCustomField].self, source: source)
            }
            // Decoder for ShortCustomField
            Decoders.addDecoder(clazz: ShortCustomField.self) { (source: AnyObject) -> ShortCustomField in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = ShortCustomField()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.name = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["name"])
                instance.fieldType = ShortCustomField.FieldType(rawValue: (sourceDictionary["field_type"] as? String) ?? "") 
                return instance
            }


            // Decoder for [Timeline]
            Decoders.addDecoder(clazz: [Timeline].self) { (source: AnyObject) -> [Timeline] in
                return Decoders.decode(clazz: [Timeline].self, source: source)
            }
            // Decoder for Timeline
            Decoders.addDecoder(clazz: Timeline.self) { (source: AnyObject) -> Timeline in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = Timeline()
                instance.firstOnline = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["firstOnline"])
                instance.publisherPublication = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["publisherPublication"])
                instance.publisherAcceptance = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["publisherAcceptance"])
                return instance
            }


            // Decoder for [TimelineUpdate]
            Decoders.addDecoder(clazz: [TimelineUpdate].self) { (source: AnyObject) -> [TimelineUpdate] in
                return Decoders.decode(clazz: [TimelineUpdate].self, source: source)
            }
            // Decoder for TimelineUpdate
            Decoders.addDecoder(clazz: TimelineUpdate.self) { (source: AnyObject) -> TimelineUpdate in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = TimelineUpdate()
                instance.firstOnline = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["firstOnline"])
                instance.publisherPublication = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["publisherPublication"])
                instance.publisherAcceptance = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["publisherAcceptance"])
                return instance
            }


            // Decoder for [UploadFilePart]
            Decoders.addDecoder(clazz: [UploadFilePart].self) { (source: AnyObject) -> [UploadFilePart] in
                return Decoders.decode(clazz: [UploadFilePart].self, source: source)
            }
            // Decoder for UploadFilePart
            Decoders.addDecoder(clazz: UploadFilePart.self) { (source: AnyObject) -> UploadFilePart in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = UploadFilePart()
                instance.partNo = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["partNo"])
                instance.startOffset = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["startOffset"])
                instance.endOffset = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["endOffset"])
                instance.status = UploadFilePart.Status(rawValue: (sourceDictionary["status"] as? String) ?? "") 
                instance.locked = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["locked"])
                return instance
            }


            // Decoder for [UploadInfo]
            Decoders.addDecoder(clazz: [UploadInfo].self) { (source: AnyObject) -> [UploadInfo] in
                return Decoders.decode(clazz: [UploadInfo].self, source: source)
            }
            // Decoder for UploadInfo
            Decoders.addDecoder(clazz: UploadInfo.self) { (source: AnyObject) -> UploadInfo in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = UploadInfo()
                instance.token = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["token"])
                instance.md5 = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["md5"])
                instance.size = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["size"])
                instance.name = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["name"])
                instance.status = UploadInfo.Status(rawValue: (sourceDictionary["status"] as? String) ?? "") 
                instance.parts = Decoders.decodeOptional(clazz: Array.self, source: sourceDictionary["parts"])
                return instance
            }


            // Decoder for [User]
            Decoders.addDecoder(clazz: [User].self) { (source: AnyObject) -> [User] in
                return Decoders.decode(clazz: [User].self, source: source)
            }
            // Decoder for User
            Decoders.addDecoder(clazz: User.self) { (source: AnyObject) -> User in
                let sourceDictionary = source as! [NSObject:AnyObject]
                let instance = User()
                instance.id = Decoders.decodeOptional(clazz: Int64.self, source: sourceDictionary["id"])
                instance.firstName = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["first_name"])
                instance.lastName = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["last_name"])
                instance.name = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["name"])
                instance.isActive = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_active"])
                instance.urlName = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["url_name"])
                instance.isPublic = Decoders.decodeOptional(clazz: Bool.self, source: sourceDictionary["is_public"])
                instance.jobTitle = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["job_title"])
                instance.orcidId = Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["orcid_id"])
                return instance
            }
        }
    }
}
